## cdist-type__hostname(7)

### Steven Armstrong

`<steven-cdist--@--armstrong.cc>`

## 1. NAME

cdist-type__hostname - set the hostname

## 2. DESCRIPTION

Set’s the hostname on various operating systems.

## 3. REQUIRED PARAMETERS

None.

## 4. OPTIONAL PARAMETERS

name
  The hostname to set. Defaults to the first segment of target_host (${target_host%%.*})

## 5. MESSAGES

changed
  Changed the hostname

## 6. EXAMPLES

    # take hostname from __target_host
    __hostname

    # set hostname explicitly
    __hostname --name some-static-hostname

## 7. SEE ALSO

- cdist-type(7)

## 8. COPYING

Copyright (C) 2012 Steven Armstrong. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).